@@ -1,7 +1,7 @@
 import unittest
 from os import path
 import sys
-# sys.path.append(path.abspath(path.dirname(path.dirname(__file__))))
+sys.path.append(path.abspath(path.dirname(path.dirname(__file__))))
 
 from usageFinderTest import KeywordUsageFinderTest, VariableUsageFinderTest
 from testDataDependencyBuilderTest import TestDataDependencyBuilderTest
